@@ -171,7 +171,7 @@ use PPIx::Regexp::Tokenizer;
 use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.066_01';
+our $VERSION = '0.067_01';
 
 =head2 new
 
@@ -772,7 +772,7 @@ guess. That is, it employs various heuristics on the code to try to
 figure out what the programmer wanted. These heuristics are documented
 as being undocumented (!) and subject to change without notice. As an
 example of the problems even F<perl> faces in parsing Perl, see
-L<https://rt.perl.org/Public/Bug/Display.html?id=133027>.
+L<https://github.com/perl/perl5/issues/16478>.
 
 Given this situation, this module's chances of duplicating every Perl
 version's interpretation of every regular expression are pretty much nil.
@@ -908,7 +908,7 @@ is again supported.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -916,7 +916,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2019 by Thomas R. Wyant, III
+Copyright (C) 2009-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
