@@ -12,12 +12,13 @@ use Scalar::Util qw{ blessed };
 use base qw{ Exporter };
 
 our @EXPORT_OK = qw{
+    is_ppi_regexp_element
     __choose_tokenizer_class __instance
     __is_ppi_regexp_element
     __ns_can __to_ordinal_en
 };
 
-our $VERSION = '0.066_01';
+our $VERSION = '0.067_01';
 
 {
 
@@ -37,8 +38,10 @@ our $VERSION = '0.066_01';
 	    'PPIx::Regexp::StringTokenizer' ],
     );
 
-    sub __is_ppi_regexp_element {
+    sub is_ppi_regexp_element {
 	my ( $elem ) = @_;
+	__instance( $elem, 'PPI::Element' )
+	    or return;
 	foreach ( @ppi_zoo ) {
 	    $elem->isa( $_->[0] )
 		or next;
@@ -47,6 +50,13 @@ our $VERSION = '0.066_01';
 	return;
     }
 
+    sub __is_ppi_regexp_element {
+	Carp::cluck(
+	    '__is_ppi_regexp_element is deprecated. Use is_ppi_regexp_element'
+	);
+	goto &is_ppi_regexp_element;
+    }
+
     my %parse_type = (
 	guess	=> sub {
 	    my ( $content ) = @_;
@@ -109,6 +119,8 @@ sub __ns_can {
 sub __to_ordinal_en {
     my ( $num ) = @_;
     $num += 0;
+    1 == int( ( $num % 100 ) / 10 )	# teens
+	and return "${num}th";
     1 == $num % 10
 	and return "${num}st";
     2 == $num % 10
@@ -140,10 +152,9 @@ PPIx::Regexp::Util - Utility functions for PPIx::Regexp;
 This module contains utility functions for L<PPIx::Regexp|PPIx::Regexp>
 which it is convenient to centralize.
 
-The contents of this module are B<private> to the
-L<PPIx::Regexp|PPIx::Regexp> package. This documentation is provided for
-the author's convenience only. Anything in this module is subject to
-change without notice. I<Caveat user.>
+Double-underscore subroutines are B<private> to the C<PPIx-Regexp>
+package. Their documentation is provided for the author's convenience
+only, and they are subject to change without notice. I<Caveat user.>
 
 This module exports nothing by default.
 
@@ -151,11 +162,24 @@ This module exports nothing by default.
 
 This module can export the following subroutines:
 
+=head2 is_ppi_regexp_element
+
+ is_ppi_regexp_element( $elem )
+   and print "$elem is a regexp of some sort\n";
+
+This subroutine is public and supported.
+
+This subroutine takes as its argument a L<PPI::Element|PPI::Element>. It
+returns a true value if the argument represents a regular expression of
+some sort, and a false value otherwise.
+
 =head2 __instance
 
  __instance( $foo, 'Bar' )
      and print '$foo isa Bar', "\n";
 
+This subroutine is B<private> to the C<PPIx-Regexp> package.
+
 This subroutine returns true if its first argument is an instance of the
 class specified by its second argument. Unlike C<UNIVERSAL::isa>, the
 result is always false unless the first argument is a reference.
@@ -165,17 +189,23 @@ result is always false unless the first argument is a reference.
  __is_ppi_regexp_element( $elem )
    and print "$elem is a regexp of some sort\n";
 
-This subroutine takes as its argument a L<PPI::Element|PPI::Element>. It
-returns a true value if the argument represents a regular expression of
-some sort, and a false value otherwise.
+This subroutine is B<private> to the C<PPIx-Regexp> package.
+
+This is a synonym for L<is_ppi_regexp_element()|/is_ppi_regexp_element>,
+and is deprecated in favor of it. If called, it will complain via
+C<Carp::cluck()> and then C<goto &is_ppi_regexp_element>.
 
 =head2 __ns_can
 
+This subroutine is B<private> to the C<PPIx-Regexp> package.
+
 This method is analogous to C<can()>, but returns a reference to the
 code only if it is actually implemented by the invoking name space.
 
 =head2 __to_ordinal_en
 
+This subroutine is B<private> to the C<PPIx-Regexp> package.
+
 This subroutine takes as its argument an integer and returns a string
 representing its ordinal in English. For example
 
@@ -196,7 +226,7 @@ C<_INSTANCE()> subroutine.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -204,7 +234,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2019 by Thomas R. Wyant, III
+Copyright (C) 2010-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
